@@ -1,11 +1,6 @@
 import os
 
-from netops.utils.utils import print_json
-
-from .port_mapping import (
-    get_junos_lo_configs,
-    get_linux_lo_configs
-)
+from .port_mapping import get_junos_lo_configs
 from ..api.netbox.netbox_manager import NetboxManager
 from ..api.netbox.util import get_sot_filter_parameters
 from ..configs.configs import ( 
@@ -29,8 +24,7 @@ def los_config_generate(topo=None):
             topo: lista de links (dicionarios de {'id': <int>, 'endpoint_a': {'host': <str>, 'interface': <str>}}
     Retorna:
             dev_config_description - objeto dicionario (config.models.config_descr) contendo a 
-            descricao das alteracoes de configuracao associadas a cada dispositivo
-    """
+            descricao das alteracoes de configuracao associadas a cada dispositivo"""
     dev_config_description = config_descr()
 
     filter_params = get_sot_filter_parameters()
@@ -40,16 +34,12 @@ def los_config_generate(topo=None):
 
     for host in nr_inv.hosts:
         host_data = nr_inv.hosts[host].data
-        # print("Host data: \n") #################################################################
-        
-        # print_json(host_data) #################################################################
-        #manufacturer = host_data['device_type']['manufacturer']['name']
-        platform = host_data['platform']['slug']
+        manufacturer = host_data['device_type']['manufacturer']['name']
         con_ints=[]
         if topo:
             for link in topo:
-                host_a = link['endpoint_a']['host']['name']
-                host_z = link['endpoint_z']['host']['name']
+                host_a = link['endpoint_a']['host']
+                host_z = link['endpoint_z']['host']
                 # Link ID is used to identify interface per link
                 if host == host_a:
                     con_ints.append({'id': link['id'], 'iface': link['endpoint_a']['interface']})
@@ -57,15 +47,11 @@ def los_config_generate(topo=None):
                     con_ints.append({'id': link['id'], 'iface': link['endpoint_z']['interface']})
         if con_ints == []:
             con_ints=None 
-        if platform == 'junos':
-            lo_configs = get_junos_lo_configs(nornir=nr, dev_name=host, connected_interfaces=con_ints).splitlines()
-        elif platform == 'linux':
-            #TO-DO create get linux configs based on interface
-            lo_configs = get_linux_lo_configs(nornir=nr, dev_name=host).splitlines()
+        lo_configs = get_junos_lo_configs(nornir=nr, dev_name=host, connected_interfaces=con_ints).splitlines()
         dev_config_type = 'procedural'
         dev_full_config = describe_dev_config(
             device=host,
-            platform=platform,
+            platform=manufacturer,
             configs=[
                 (dev_config_type, lo_configs)
             ]
